Module nodes
forgekit_
core
0.5.0
Module nodes
Module Items
Structs
In forgekit_
core::
knowledge
forgekit_core
::
knowledge
Module
nodes
Structs

Span
Byte range of a symbol within its source file, used when inserting symbol nodes into the knowledge graph.