pub struct SourceSpan {
pub file: String,
pub line: usize,
pub byte_start: u32,
pub byte_end: u32,
}Expand description
Byte range of a symbol within its source file, used when inserting symbol nodes into the knowledge graph.
Fields
file: Stringline: usizebyte_start: u32byte_end: u32Implementations