pub struct Forge { /* private fields */ }Expand description
Main entry point for ForgeKit SDK.
The Forge type provides access to all code intelligence modules.
Implementations
Sourceimpl Forge
impl Forge
Sourcepub async fn open_with_backend(
path: impl AsRef<Path>,
backend: BackendKind,
) -> Result<Self>
pub async fn open_with_backend( path: impl AsRef<Path>, backend: BackendKind, ) -> Result<Self>
Sourcepub fn backend_kind(&self) -> BackendKind
pub fn backend_kind(&self) -> BackendKind
Returns the backend kind currently in use.
Sourcepub fn graph(&self) -> GraphModule
pub fn graph(&self) -> GraphModule
Returns the graph module for symbol and reference queries.
Sourcepub fn search(&self) -> SearchModule
pub fn search(&self) -> SearchModule
Returns the search module for semantic code queries.
Sourcepub fn edit(&self) -> EditModule
pub fn edit(&self) -> EditModule
Returns the edit module for span-safe refactoring.
Sourcepub fn analysis(&self) -> AnalysisModule
pub fn analysis(&self) -> AnalysisModule
Returns the analysis module for combined operations.
Sourcepub fn build(&self) -> Option<BuildModule>
pub fn build(&self) -> Option<BuildModule>
Returns the build module for build system operations.
Detects the build system from the codebase root. Returns None if
no known build system is detected.
Sourcepub fn as_workspace(&self) -> Result<Workspace>
pub fn as_workspace(&self) -> Result<Workspace>
Returns the workspace view for monorepo awareness.
Sourcepub fn project(&self) -> ProjectModule
pub fn project(&self) -> ProjectModule
Returns the project module for scaffolding and detection.
Sourcepub fn dependency(&self) -> DependencyModule
pub fn dependency(&self) -> DependencyModule
Returns the dependency module for manifest operations.
Sourcepub fn codebase_path(&self) -> &Path
pub fn codebase_path(&self) -> &Path
Returns the codebase path.